@@ -6,7 +6,7 @@ use base qw/Catalyst::View/;
 
 use Data::Dumper;
 
-our $VERSION = '2.2_002';
+our $VERSION = '2.1';
 
 
 =head1 NAME
@@ -25,8 +25,7 @@ Catalyst::View::Seamstress - HTML::Seamstress View Class for Catalyst
 # in lib/MyApp/View/Seamstress.pm
 
 # create your seamstress template packaged with spkg.pl
-# see HTML::Seamstress.. This will give you a .pm file to go with your html, 
-# so something like html::helloworld
+# see HTML::Seamstress
 
 # render view from lib/MyApp.pm or lib/MyApp::C::SomeController.pm
 
@@ -43,14 +42,6 @@ Catalyst::View::Seamstress - HTML::Seamstress View Class for Catalyst
         $c->forward('MyApp::View::Seamstress');
     }
 
-# and in your html::helloworld you can do something like:
-
- sub process{
-     my( $tree, $c, $stash ) = @_;
-     
-     $tree->look_down( id => 'name' )->replace_content( $stash->{name}
- }
-
 
 =head1 DESCRIPTION
 
@@ -244,8 +235,6 @@ sub page2tree {
 sub process {
     my ( $self, $c ) = @_;
 
-    my $body_is_skeleton = 0;
-
     my ($skeleton, $meat, $body) ;
 
     my $loom = $c->stash->{LOOM};
@@ -282,7 +271,9 @@ sub process {
           $self, $c, $c->stash, $meat, $skeleton
        );
 
-      $body_is_skeleton = 1;
+      # $body = $self->page2tree($c, $skeleton, 'fixup');
+      # this should be additional controller actions for the request
+
       $body = $skeleton ;
     }
 
@@ -305,9 +296,9 @@ sub process {
     $c->response->body( $response_body );
 
 
-    # we delete the body unless our loom ( or skeleton if we have one) is a reference
-    # which we take as a sign that the user is doing something more elaborate caching or something..
-    unless( (! $body_is_skeleton && ref $loom)  ||  ( $body_is_skeleton && ref $self->config->{skeleton} ) ) {
+    # If loom is a class-name we're not doing anything especially fancy, so
+    # we'll just delete it:
+    unless ( ref $loom ) {
         $body->delete;
     }
 
